# tajm2

tajm2 is a command line GUI tool built on Textual to manage time slots.

> _"tajm2 is the only tool needed keeping track of my time slots."_ -The author

The data is stored locally in a SQLite3 database. You'll need to have Python installed and from a command prompt enter:

```
pip install tajm2
tajm2
```